@@ -1,8 +1,10 @@
 import tkinter as tk
+import time
 
 tkWindow = tk.Tk()
-tkWindow.geometry('295x367')
-tkWindow.title('KeyloggerScreenshot by Fawaz Abolagi Temitaiu Martin Junior Bashiru')
+tkWindow.geometry('220x322')
+kurz = "by Fawaz Abolagi Temitaiu Martin Junior Bashiru"
+tkWindow.title('KeyloggerScreenshot')
 started = False
 def changecol(newstate):
     if newstate == True:
@@ -23,8 +25,7 @@ def start_stop():
     changecol(started)
 def show_files():
     print("showing_files")
-
-startbutton = tk.Button(tkWindow, text="Start KLS", command=start_stop, height=10, width=30)
+startbutton = tk.Button(tkWindow, text="Stop simulation", command=start_stop, height=10, width=30)
 startbutton.grid(row=1, column=0)
-tk.Button(tkWindow, text="Show Files", command=show_files, height=10, width=30).grid(row=2, column=0)
+tk.Button(tkWindow, text="Simulation for 50 seconds", command=show_files, height=10, width=30).grid(row=2, column=0)
 tkWindow.mainloop()
\ No newline at end of file
